@@ -212,7 +212,7 @@ func TestLoadKustomize(t *testing.T) {
 			name:            "erroneous-pod",
 			basepath:        filepath.Join(testDataDir, "erroneous-pod"),
 			filename:        kustomizeYaml,
-			wantErr:         fmt.Errorf(kustomizeErrPrefix),
+			wantErr:         fmt.Errorf(kustomizeErrPrefix), //lint:ignore SA1006 placeholder %s are specified in string constants
 			checkPrefix:     true,
 			kustomizeBinary: false,
 			exe:             "",
@@ -221,7 +221,7 @@ func TestLoadKustomize(t *testing.T) {
 			name:            "erroneous-deployment",
 			basepath:        filepath.Join(testDataDir, "erroneous-deployment/"),
 			filename:        kustomizeYaml,
-			wantErr:         fmt.Errorf(kustomizeErrPrefix),
+			wantErr:         fmt.Errorf(kustomizeErrPrefix), //lint:ignore SA1006 placeholder %s are specified in string constants
 			checkPrefix:     true,
 			kustomizeBinary: false,
 			exe:             "",
