@@ -200,7 +200,7 @@ func (v *Vulnerability) PrepareFromACRImageScan(acrResponse ACRResponse) {
 		return
 	}
 	v.Description = acrResponse.Properties.Description
-	if acrResponse.Properties.AdditionalData.Cve != nil && len(acrResponse.Properties.AdditionalData.Cve) >= 1 {
+	if len(acrResponse.Properties.AdditionalData.Cve) >= 1 {
 		v.VulnerabilityID = acrResponse.Properties.AdditionalData.Cve[0].Title
 		v.PrimaryURL = acrResponse.Properties.AdditionalData.Cve[0].Link
 	}
