@@ -1,11 +1,12 @@
 package iacprovider
 
 import (
-	tfv15 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v15"
 	"reflect"
 
-	tfv12 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v12"
-	tfv14 "github.com/accurics/terrascan/pkg/iac-providers/terraform/v14"
+	tfv15 "github.com/tenable/terrascan/pkg/iac-providers/terraform/v15"
+
+	tfv12 "github.com/tenable/terrascan/pkg/iac-providers/terraform/v12"
+	tfv14 "github.com/tenable/terrascan/pkg/iac-providers/terraform/v14"
 )
 
 // terraform specific constants
