@@ -23,5 +23,5 @@ import (
 
 // LoadIacFile parses the given terraform file from the given file path
 func (*TfV15) LoadIacFile(absFilePath string, options map[string]interface{}) (allResourcesConfig output.AllResourceConfigs, err error) {
-	return commons.LoadIacFile(absFilePath)
+	return commons.LoadIacFile(absFilePath, version)
 }
