@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const (
@@ -51,7 +52,7 @@ func KubernetesClusterConfig(r types.Resource, vars, params map[string]interface
 	cf := map[string]interface{}{
 		tfLocation:  fn.LookUpString(nil, params, r.Location),
 		tfName:      fn.LookUpString(nil, params, r.Name),
-		tfTags:      r.Tags,
+		tfTags:      functions.PatchAWSTags(r.Tags),
 		tfDNSPrefix: fn.LookUpString(vars, params, convert.ToString(r.Properties, armDNSPrefix)),
 	}
 
