@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const (
@@ -43,7 +44,7 @@ func ManagedDiskConfig(r types.Resource, vars, params map[string]interface{}) ma
 	cf := map[string]interface{}{
 		tfLocation:           fn.LookUpString(nil, params, r.Location),
 		tfName:               fn.LookUpString(nil, params, r.Name),
-		tfTags:               r.Tags,
+		tfTags:               functions.PatchAWSTags(r.Tags),
 		tfStorageAccountType: r.SKU.Name,
 		tfEncryptionSettings: convert.ToMap(r.Properties, armEncryptionSettingsCollection),
 		tfDiskSizeGB:         fn.LookUpFloat64(vars, params, convert.ToString(r.Properties, armDiskSizeGB)),
