@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const (
@@ -50,7 +51,7 @@ func NetworkWatcherFlowLogConfig(r types.Resource, vars, params map[string]inter
 	cf := map[string]interface{}{
 		tfLocation:               fn.LookUpString(nil, params, r.Location),
 		tfName:                   fn.LookUpString(nil, params, r.Name),
-		tfTags:                   r.Tags,
+		tfTags:                   functions.PatchAWSTags(r.Tags),
 		tfNetworkSecurityGroupID: fn.LookUpString(vars, params, convert.ToString(r.Properties, armTargetResourceID)),
 		tfStorageAccountID:       fn.LookUpString(vars, params, convert.ToString(r.Properties, armStorageID)),
 		tfEnabled:                convert.ToBool(r.Properties, armEnabled),
