@@ -22,6 +22,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // PostgreSQLServerConfig returns config for azurerm_postgresql_server
@@ -29,7 +30,7 @@ func PostgreSQLServerConfig(r types.Resource, vars, params map[string]interface{
 	cf := map[string]interface{}{
 		tfLocation: fn.LookUpString(nil, params, r.Location),
 		tfName:     fn.LookUpString(nil, params, r.Name),
-		tfTags:     r.Tags,
+		tfTags:     functions.PatchAWSTags(r.Tags),
 		tfSkuName:  fn.LookUpString(vars, params, r.SKU.Name),
 		tfVersion:  fn.LookUpString(vars, params, convert.ToString(r.Properties, armVersion)),
 	}
