@@ -20,6 +20,7 @@ import (
 	"github.com/tenable/terrascan/pkg/mapper/convert"
 	fn "github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/functions"
 	"github.com/tenable/terrascan/pkg/mapper/iac-providers/arm/types"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 const (
@@ -44,7 +45,7 @@ func StorageAccountConfig(r types.Resource, vars, params map[string]interface{})
 	cf := map[string]interface{}{
 		tfLocation:               fn.LookUpString(nil, params, r.Location),
 		tfName:                   fn.LookUpString(nil, params, r.Name),
-		tfTags:                   r.Tags,
+		tfTags:                   functions.PatchAWSTags(r.Tags),
 		tfAccountTier:            r.SKU.Tier,
 		tfAccountReplicationType: r.SKU.Name,
 		tfEnableHTTPSTrafficOnly: convert.ToBool(r.Properties, armSupportsHTTPSTrafficOnly),
