@@ -18,6 +18,7 @@ package config
 
 import (
 	"github.com/awslabs/goformation/v7/cloudformation/apigatewayv2"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // APIGatewayV2StageConfig holds config for aws_api_gatewayv2_stage
@@ -27,11 +28,12 @@ type APIGatewayV2StageConfig struct {
 }
 
 // GetAPIGatewayV2StageConfig returns config for aws_api_gatewayv2_stage
+// aws_api_gatewayv2_stage no policy
 func GetAPIGatewayV2StageConfig(s *apigatewayv2.Stage) []AWSResourceConfig {
 	cf := APIGatewayV2StageConfig{
 		Config: Config{
 			Name: s.StageName,
-			Tags: s.Tags,
+			Tags: functions.PatchAWSTags(s.Tags),
 		},
 	}
 	if s.AccessLogSettings != nil {
