@@ -39,6 +39,7 @@ type AppMeshMeshConfig struct {
 }
 
 // GetAppMeshMeshConfig returns config for AppMeshMesh
+// aws_appmesh_mesh
 func GetAppMeshMeshConfig(m *appmesh.Mesh) []AWSResourceConfig {
 	var spec []AppMeshSpecBlock
 	if m.Spec != nil {
@@ -54,7 +55,7 @@ func GetAppMeshMeshConfig(m *appmesh.Mesh) []AWSResourceConfig {
 	cf := AppMeshMeshConfig{
 		Config: Config{
 			Name: functions.GetVal(m.MeshName),
-			Tags: m.Tags,
+			Tags: functions.PatchAWSTags(m.Tags),
 		},
 		Name: functions.GetVal(m.MeshName),
 		Spec: spec,
