@@ -31,10 +31,11 @@ type Ec2VpcConfig struct {
 }
 
 // GetEc2VpcConfig returns config for Ec2Vpc
+// aws_vpc
 func GetEc2VpcConfig(v *ec2.VPC) []AWSResourceConfig {
 	cf := Ec2VpcConfig{
 		Config: Config{
-			Tags: v.Tags,
+			Tags: functions.PatchAWSTags(v.Tags),
 		},
 		CIDRBlock:          functions.GetVal(v.CidrBlock),
 		EnableDNSSupport:   functions.GetVal(v.EnableDnsSupport),
