@@ -18,6 +18,7 @@ package config
 
 import (
 	"github.com/awslabs/goformation/v7/cloudformation/ec2"
+	"github.com/tenable/terrascan/pkg/mapper/iac-providers/cft/functions"
 )
 
 // RouteTableConfig holds config for aws_route_table
@@ -27,10 +28,11 @@ type RouteTableConfig struct {
 }
 
 // GetRouteTableConfig returns config for aws_route_table
+// aws_route_table
 func GetRouteTableConfig(e *ec2.RouteTable) []AWSResourceConfig {
 	cf := RouteTableConfig{
 		Config: Config{
-			Tags: e.Tags,
+			Tags: functions.PatchAWSTags(e.Tags),
 		},
 		VpcID: e.VpcId,
 	}
