@@ -27,21 +27,33 @@ import (
 const (
 	// PublicAccessBlock represents subresource aws_s3_bucket_public_access_block for attribute PublicAccessBlockConfiguration
 	PublicAccessBlock = "PublicAccessBlock"
+	// ServerSideEncription represents subresource aws_s3_bucket for attribute aws_s3_bucket_server_side_encryption_configuration
+	ServerSideEncription = "ServerSideEncription"
+	// Versioning represents subresource aws_s3_bucket for attribute aws_s3_bucket_versioning
+	Versioning = "Versioning"
 )
 
+// BucketConfig holds common config for aws_s3_bucket
+type BucketConfig struct {
+	Config
+	ProviderVersion string `json:"provider_version"`
+}
+
 // S3BucketConfig holds config for aws_s3_bucket
 type S3BucketConfig struct {
-	Config
-	Bucket               string                       `json:"bucket"`
-	AccessControl        string                       `json:"acl"`
-	BucketEncryption     []ServerSideEncryptionConfig `json:"server_side_encryption_configuration,omitempty"`
-	Logging              []LoggingConfig              `json:"logging"`
-	WebsiteConfiguration []WebsiteConfig              `json:"website"`
-	Versioning           []VersioningConfig           `json:"versioning,omitempty"`
+	BucketConfig
+	Bucket        string `json:"bucket"`
+	AccessControl string `json:"acl"`
+	// BucketEncryption     []ServerSideEncryptionConfig `json:"server_side_encryption_configuration,omitempty"`
+	Logging              []LoggingConfig    `json:"logging"`
+	WebsiteConfiguration []WebsiteConfig    `json:"website"`
+	Versioning           []VersioningConfig `json:"versioning,omitempty"`
 }
 
 // ServerSideEncryptionConfig holds config for server_side_encryption_configuration
 type ServerSideEncryptionConfig struct {
+	BucketConfig
+	Bucket                            string                     `json:"bucket"`
 	ServerSideEncryptionConfiguration []ServerSideEncryptionRule `json:"rule"`
 }
 
@@ -78,7 +90,7 @@ type VersioningConfig struct {
 
 // S3BucketPublicAccessBlockConfig holds config for aws_s3_bucket_public_access_block
 type S3BucketPublicAccessBlockConfig struct {
-	Config
+	BucketConfig
 	Bucket                string `json:"bucket"`
 	BlockPublicAcls       bool   `json:"block_public_acls"`
 	BlockPublicPolicy     bool   `json:"block_public_policy"`
@@ -87,37 +99,21 @@ type S3BucketPublicAccessBlockConfig struct {
 }
 
 // GetS3BucketConfig returns config for aws_s3_bucket
-func GetS3BucketConfig(s *s3.Bucket) []AWSResourceConfig {
+func GetS3BucketConfig(s *s3.Bucket, resourceName string) []AWSResourceConfig {
 	resourceConfigs := make([]AWSResourceConfig, 0)
 
 	cf := S3BucketConfig{
-		Config: Config{
-			Name: functions.GetVal(s.BucketName),
-			Tags: s.Tags,
+		BucketConfig: BucketConfig{
+			Config: Config{
+				Name: functions.GetVal(s.BucketName),
+				Tags: s.Tags,
+			},
+			ProviderVersion: "5.0.0",
 		},
 		Bucket:        functions.GetVal(s.BucketName),
 		AccessControl: strings.ToLower(functions.GetVal(s.AccessControl)),
 	}
 
-	// add sse configurations
-	if s.BucketEncryption != nil {
-		sseRules := make([]ServerSideEncryptionRule, 0)
-		for _, sseRule := range s.BucketEncryption.ServerSideEncryptionConfiguration {
-			if sseRule.ServerSideEncryptionByDefault != nil {
-				defaultConfig := DefaultSSEConfig{
-					KMSMasterKeyID: functions.GetVal(sseRule.ServerSideEncryptionByDefault.KMSMasterKeyID),
-					SSEAlgorithm:   sseRule.ServerSideEncryptionByDefault.SSEAlgorithm,
-				}
-				sseRules = append(sseRules, ServerSideEncryptionRule{
-					ServerSideEncryptionByDefault: []DefaultSSEConfig{defaultConfig},
-				})
-			}
-		}
-		cf.BucketEncryption = []ServerSideEncryptionConfig{{
-			ServerSideEncryptionConfiguration: sseRules,
-		}}
-	}
-
 	// add logging configurations
 	if s.LoggingConfiguration != nil {
 		cf.Logging = []LoggingConfig{{
@@ -151,16 +147,21 @@ func GetS3BucketConfig(s *s3.Bucket) []AWSResourceConfig {
 	resourceConfigs = append(resourceConfigs, AWSResourceConfig{
 		Resource: cf,
 		Metadata: s.AWSCloudFormationMetadata,
+		Name:     resourceName,
 	})
 
 	// add aws_s3_bucket_public_access_block
 	if s.PublicAccessBlockConfiguration != nil {
 		resourceConfigs = append(resourceConfigs, AWSResourceConfig{
 			Resource: S3BucketPublicAccessBlockConfig{
-				Config: Config{
-					Name: functions.GetVal(s.BucketName),
+				BucketConfig: BucketConfig{
+					Config: Config{
+						Name: functions.GetVal(s.BucketName),
+						Tags: s.Tags,
+					},
+					ProviderVersion: "5.0.0",
 				},
-				Bucket:                fmt.Sprintf("aws_s3_bucket.%s", functions.GetVal(s.BucketName)),
+				Bucket:                fmt.Sprintf("aws_s3_bucket.%s", resourceName),
 				BlockPublicAcls:       functions.GetVal(s.PublicAccessBlockConfiguration.BlockPublicAcls),
 				BlockPublicPolicy:     functions.GetVal(s.PublicAccessBlockConfiguration.BlockPublicPolicy),
 				IgnorePublicAcls:      functions.GetVal(s.PublicAccessBlockConfiguration.IgnorePublicAcls),
@@ -172,5 +173,40 @@ func GetS3BucketConfig(s *s3.Bucket) []AWSResourceConfig {
 		})
 	}
 
+	// add aws_s3_bucket_server_side_encryption_configuration
+	if s.BucketEncryption != nil {
+		sseRules2 := make([]ServerSideEncryptionRule, 0)
+		for _, sseRule := range s.BucketEncryption.ServerSideEncryptionConfiguration {
+
+			if sseRule.ServerSideEncryptionByDefault != nil {
+
+				defaultConfig := DefaultSSEConfig{
+					KMSMasterKeyID: functions.GetVal(sseRule.ServerSideEncryptionByDefault.KMSMasterKeyID),
+					SSEAlgorithm:   sseRule.ServerSideEncryptionByDefault.SSEAlgorithm,
+				}
+				sseRules2 = append(sseRules2, ServerSideEncryptionRule{
+					BucketKeyEnabled:              functions.GetVal(sseRule.BucketKeyEnabled),
+					ServerSideEncryptionByDefault: []DefaultSSEConfig{defaultConfig},
+				})
+			}
+		}
+		resourceConfigs = append(resourceConfigs, AWSResourceConfig{
+			Resource: ServerSideEncryptionConfig{
+				BucketConfig: BucketConfig{
+					Config: Config{
+						Name: functions.GetVal(s.BucketName),
+						Tags: s.Tags,
+					},
+					ProviderVersion: "5.0.0",
+				},
+				Bucket:                            fmt.Sprintf("aws_s3_bucket.%s", resourceName),
+				ServerSideEncryptionConfiguration: sseRules2,
+			},
+			Metadata: s.AWSCloudFormationMetadata,
+			Type:     ServerSideEncription,
+			Name:     functions.GetVal(s.BucketName),
+		})
+	}
+
 	return resourceConfigs
 }
