@@ -33,11 +33,12 @@ type SagemakerNotebookInstanceConfig struct {
 }
 
 // GetSagemakerNotebookInstanceConfig returns config for SagemakerNotebookInstance
+// aws_sagemaker_notebook_instance
 func GetSagemakerNotebookInstanceConfig(n *sagemaker.NotebookInstance) []AWSResourceConfig {
 	cf := SagemakerNotebookInstanceConfig{
 		Config: Config{
 			Name: functions.GetVal(n.NotebookInstanceName),
-			Tags: n.Tags,
+			Tags: functions.PatchAWSTags(n.Tags),
 		},
 		Name:                 functions.GetVal(n.NotebookInstanceName),
 		RoleARN:              n.RoleArn,
