@@ -18,7 +18,6 @@ package utils
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 
 	"go.uber.org/zap"
@@ -26,7 +25,7 @@ import (
 
 // CreateTempFile creates a file with provided contents in the temp directory
 func CreateTempFile(content []byte, ext string) (*os.File, error) {
-	tempFile, err := ioutil.TempFile("", fmt.Sprintf("terrascan-*.%s", ext))
+	tempFile, err := os.CreateTemp("", fmt.Sprintf("terrascan-*.%s", ext))
 	if err != nil {
 		zap.S().Errorf("failed to create temp file: '%v'", err)
 		return nil, err
