@@ -131,7 +131,7 @@ var _ = Describe("Scan", func() {
 				})
 
 				When("tf file present in the dir has no violations", func() {
-					Context("when there are no violations, but has dir scan erros, terrascan exits with status code 4", func() {
+					Context("when there are no violations, but has dir scan errors, terrascan exits with status code 4", func() {
 						It("should scan the directory and exit with status code 0", func() {
 							workDir, err := filepath.Abs(filepath.Join(awsIacRelPath, "aws_db_instance_violation"))
 							Expect(err).NotTo(HaveOccurred())
@@ -263,7 +263,7 @@ var _ = Describe("Scan", func() {
 
 		Context("multiple policy paths can be supplied", func() {
 			When("one of the supplied policy path is invalid", func() {
-				It("should error out and exit with staus code 1", func() {
+				It("should error out and exit with status code 1", func() {
 					validPolicyPath, err := filepath.Abs(filepath.Join("..", "test_data"))
 					Expect(err).NotTo(HaveOccurred())
 					scanArgs := []string{scanUtils.ScanCommand, "-p", validPolicyPath, "-p", invalidPolicyPath}
@@ -328,7 +328,7 @@ var _ = Describe("Scan", func() {
 		Context("valid --webhook-url and --webhook-token flag is supplied", func() {
 			It("should scan and display violations in human output format and exit with status code 3", func() {
 				scanArgs := []string{"-p", policyDir, "-i", "terraform", "-d", iacDir, "--webhook-url", notificationURL, "--webhook-token", notificationToken}
-				scanUtils.RunScanAndAssertGoldenOutputRegex(terrascanBinaryPath, filepath.Join(tfAwsAmiGoldenRelPath, "aws_ami_violation_human.txt"), helper.ExitCodeThree, false, true, outWriter, errWriter, scanArgs...)
+				scanUtils.RunScanAndAssertGoldenOutputRegexWithTimeout(terrascanBinaryPath, filepath.Join(tfAwsAmiGoldenRelPath, "aws_ami_violation_human.txt"), helper.ExitCodeThree, false, true, outWriter, errWriter, scanUtils.WebhookScanTimeout, scanArgs...)
 
 			})
 		})
@@ -336,7 +336,7 @@ var _ = Describe("Scan", func() {
 		Context("only --webhook-url flag is supplied", func() {
 			It("should scan and display violations in human output format and exit with status code 3", func() {
 				scanArgs := []string{"-p", policyDir, "-i", "terraform", "-d", iacDir, "--webhook-url", notificationURL}
-				scanUtils.RunScanAndAssertGoldenOutputRegex(terrascanBinaryPath, filepath.Join(tfAwsAmiGoldenRelPath, "aws_ami_violation_human.txt"), helper.ExitCodeThree, false, true, outWriter, errWriter, scanArgs...)
+				scanUtils.RunScanAndAssertGoldenOutputRegexWithTimeout(terrascanBinaryPath, filepath.Join(tfAwsAmiGoldenRelPath, "aws_ami_violation_human.txt"), helper.ExitCodeThree, false, true, outWriter, errWriter, scanUtils.WebhookScanTimeout, scanArgs...)
 
 			})
 		})
